@@ -5,7 +5,6 @@ mod tests {
     use ltv::*;
 
     #[derive(Debug, Ltv, Default, PartialEq, Eq)]
-    #[object(id=10, byte_order=BE)]
     struct ExampleStruct {
         #[ltv_field(1)]
         field1: u8,
@@ -14,15 +13,7 @@ mod tests {
         field2: [u8;3],
     }
 
-    #[test]
-    fn to_and_from_ltv_obj() {
-        let original_ltv = ExampleStruct { field1: 0x69, field2: [12,34,56] };
-        let ltv_bytes = original_ltv.to_ltv_object();
-
-        println!("{:?}", &ltv_bytes);
-        let new_ltv = ExampleStruct::from_ltv_object(&ltv_bytes).unwrap();
-        assert_eq!(original_ltv, new_ltv);
-    }
+   
 
     #[test]
     fn to_and_from_ltv() {
@@ -41,6 +32,17 @@ mod tests {
         #[ltv_field(2)]
         field2: Option<u8>
     }
+
+    #[test]
+    fn to_and_from_ltv_obj() {
+        let original_ltv = LTVObjectExample { field1: 55, field2: None };
+        let ltv_bytes = original_ltv.to_ltv_object();
+
+        println!("{:?}", &ltv_bytes);
+        let new_ltv = LTVObjectExample::from_ltv_object(&ltv_bytes).unwrap();
+        assert_eq!(original_ltv, new_ltv);
+    }
+
     #[test]
     fn output_test() {
         let my_object_bytes = LTVObjectExample { field1: 55, field2: None }.to_ltv_object();
@@ -60,7 +62,6 @@ mod tests {
     #[derive(Debug, LtvCollection, PartialEq, Eq)]
     enum MyObjects {
         Object1(LTVObjectExample),
-        Object2(ExampleStruct),
     }
 
     #[test]
@@ -97,16 +98,11 @@ mod tests {
     #[test]
     fn collection_obj_test_same_as_single() {
         let o1 = LTVObjectExample { field1: 55, field2: None };
-        let o2 = ExampleStruct { field1: 0x69, field2: [12,34,56] };
         assert_eq!(
             o1.to_ltv_object(),
             MyObjects::Object1(o1).to_ltv_object()
         );
 
-        assert_eq!(
-            o2.to_ltv_object(),
-            MyObjects::Object2(o2).to_ltv_object()
-        );
     }
 
     #[test]
@@ -123,4 +119,20 @@ mod tests {
         );
     }
      
+
+    #[derive(Debug, Ltv, Default, PartialEq, Eq)]
+    #[object(id = 10, length_size=1, byte_order=BE)]
+    struct LTVObjectUnnamed(u32);
+
+    #[test]
+    fn ltv_unnamed_strct() {
+        let num : u32 = 1234567;
+        let obj = LTVObjectUnnamed(num); 
+
+        assert_eq!(
+            ltv::get_ltv::<_, {ByteOrder::BE}>(&num),
+            ltv::get_ltv::<_, {ByteOrder::BE}>(&obj)
+        );
+    }
+
 }
